DEFAULTS = {
    "HOST": "http://127.0.0.1:8000",
    "BILLING_REDIRECT_URL": "/",
    "BILLING_DECLINE_REDIRECT_URL": "/",
    "OAUTH_REDIRECT_URL": "/",
    "PREFERENCES_URL": "/shop/preferences/",
    "ERROR_EMAIL_SENDER": None,
    "ERROR_EMAIL_RECEIVER": None,
}
